# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: models/runtime/cronjob.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from jetpack.models.core import core_pb2 as models_dot_core_dot_core__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='models/runtime/cronjob.proto',
  package='runtime',
  syntax='proto3',
  serialized_options=b'Z\"go.jetpack.io/axiom/models/runtime',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1cmodels/runtime/cronjob.proto\x12\x07runtime\x1a\x16models/core/core.proto\"\xad\x01\n\x07\x43ronJob\x12\x1c\n\x04meta\x18\x01 \x01(\x0b\x32\x0e.core.NodeMeta\x12\x10\n\x08\x66unction\x18\x02 \x01(\t\x12\x13\n\x0btarget_time\x18\x03 \x01(\t\x12.\n\x12target_day_of_week\x18\x04 \x01(\x0e\x32\x12.runtime.DayOfWeek\x12\x1b\n\x04unit\x18\x05 \x01(\x0e\x32\r.runtime.Unit\x12\x10\n\x08interval\x18\x06 \x01(\x03\"V\n\x12RepeatedCronJobPtr\x12\x1f\n\x04meta\x18\x01 \x01(\x0b\x32\x11.core.PointerMeta\x12\x1f\n\x05items\x18\x02 \x03(\x0b\x32\x10.runtime.CronJob*R\n\x04Unit\x12\x10\n\x0cUNKNOWN_UNIT\x10\x00\x12\x0b\n\x07SECONDS\x10\x01\x12\x0b\n\x07MINUTES\x10\x02\x12\t\n\x05HOURS\x10\x03\x12\x08\n\x04\x44\x41YS\x10\x04\x12\t\n\x05WEEKS\x10\x05*x\n\tDayOfWeek\x12\x0f\n\x0bUNKNOWN_DAY\x10\x00\x12\n\n\x06SUNDAY\x10\x01\x12\n\n\x06MONDAY\x10\x02\x12\x0b\n\x07TUESDAY\x10\x03\x12\r\n\tWEDNESDAY\x10\x04\x12\x0c\n\x08THURSDAY\x10\x05\x12\n\n\x06\x46RIDAY\x10\x06\x12\x0c\n\x08SATURDAY\x10\x07\x42$Z\"go.jetpack.io/axiom/models/runtimeb\x06proto3'
  ,
  dependencies=[models_dot_core_dot_core__pb2.DESCRIPTOR,])

_UNIT = _descriptor.EnumDescriptor(
  name='Unit',
  full_name='runtime.Unit',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_UNIT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECONDS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MINUTES', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOURS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DAYS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEEKS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=329,
  serialized_end=411,
)
_sym_db.RegisterEnumDescriptor(_UNIT)

Unit = enum_type_wrapper.EnumTypeWrapper(_UNIT)
_DAYOFWEEK = _descriptor.EnumDescriptor(
  name='DayOfWeek',
  full_name='runtime.DayOfWeek',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_DAY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUNDAY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONDAY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TUESDAY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEDNESDAY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THURSDAY', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FRIDAY', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SATURDAY', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=413,
  serialized_end=533,
)
_sym_db.RegisterEnumDescriptor(_DAYOFWEEK)

DayOfWeek = enum_type_wrapper.EnumTypeWrapper(_DAYOFWEEK)
UNKNOWN_UNIT = 0
SECONDS = 1
MINUTES = 2
HOURS = 3
DAYS = 4
WEEKS = 5
UNKNOWN_DAY = 0
SUNDAY = 1
MONDAY = 2
TUESDAY = 3
WEDNESDAY = 4
THURSDAY = 5
FRIDAY = 6
SATURDAY = 7



_CRONJOB = _descriptor.Descriptor(
  name='CronJob',
  full_name='runtime.CronJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='runtime.CronJob.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function', full_name='runtime.CronJob.function', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_time', full_name='runtime.CronJob.target_time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_day_of_week', full_name='runtime.CronJob.target_day_of_week', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='runtime.CronJob.unit', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='runtime.CronJob.interval', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=239,
)


_REPEATEDCRONJOBPTR = _descriptor.Descriptor(
  name='RepeatedCronJobPtr',
  full_name='runtime.RepeatedCronJobPtr',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='meta', full_name='runtime.RepeatedCronJobPtr.meta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='runtime.RepeatedCronJobPtr.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=327,
)

_CRONJOB.fields_by_name['meta'].message_type = models_dot_core_dot_core__pb2._NODEMETA
_CRONJOB.fields_by_name['target_day_of_week'].enum_type = _DAYOFWEEK
_CRONJOB.fields_by_name['unit'].enum_type = _UNIT
_REPEATEDCRONJOBPTR.fields_by_name['meta'].message_type = models_dot_core_dot_core__pb2._POINTERMETA
_REPEATEDCRONJOBPTR.fields_by_name['items'].message_type = _CRONJOB
DESCRIPTOR.message_types_by_name['CronJob'] = _CRONJOB
DESCRIPTOR.message_types_by_name['RepeatedCronJobPtr'] = _REPEATEDCRONJOBPTR
DESCRIPTOR.enum_types_by_name['Unit'] = _UNIT
DESCRIPTOR.enum_types_by_name['DayOfWeek'] = _DAYOFWEEK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CronJob = _reflection.GeneratedProtocolMessageType('CronJob', (_message.Message,), {
  'DESCRIPTOR' : _CRONJOB,
  '__module__' : 'models.runtime.cronjob_pb2'
  # @@protoc_insertion_point(class_scope:runtime.CronJob)
  })
_sym_db.RegisterMessage(CronJob)

RepeatedCronJobPtr = _reflection.GeneratedProtocolMessageType('RepeatedCronJobPtr', (_message.Message,), {
  'DESCRIPTOR' : _REPEATEDCRONJOBPTR,
  '__module__' : 'models.runtime.cronjob_pb2'
  # @@protoc_insertion_point(class_scope:runtime.RepeatedCronJobPtr)
  })
_sym_db.RegisterMessage(RepeatedCronJobPtr)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
